==> openshift-model-operatorhub-5.3.0-sources.jar: annotations/io/fabric8/openshift/api/model/operatorhub/v1alpha1/ClusterServiceVersionFluentImpl.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import java.lang.Object;

public class ClusterServiceVersionFluentImpl<A extends ClusterServiceVersionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ClusterServiceVersionFluent<A> {

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private ClusterServiceVersionSpecBuilder spec;
    private ClusterServiceVersionStatusBuilder status;

    public ClusterServiceVersionFluentImpl() {
    }

    public ClusterServiceVersionFluentImpl(ClusterServiceVersion instance) {
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion() {
        return this.apiVersion;
    }

    public A withApiVersion(String apiVersion) {
        this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion() {
        return this.apiVersion != null;
    }

    public A withNewApiVersion(StringBuilder arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(int[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(char[] arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(byte[] arg1,int arg2) {
        return (A)withApiVersion(new String(arg1, arg2));
    }

    public A withNewApiVersion(byte[] arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(char[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(byte[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withApiVersion(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewApiVersion(String arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public String getKind() {
        return this.kind;
    }

    public A withKind(String kind) {
        this.kind=kind; return (A) this;
    }

    public Boolean hasKind() {
        return this.kind != null;
    }

    public A withNewKind(StringBuilder arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(int[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(char[] arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(byte[] arg1,int arg2) {
        return (A)withKind(new String(arg1, arg2));
    }

    public A withNewKind(byte[] arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(char[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(byte[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withKind(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewKind(String arg1) {
        return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata() {
        return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata() {
        return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata) {
        _visitables.get("metadata").remove(this.metadata);
        if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata() {
        return this.metadata != null;
    }

    public ClusterServiceVersionFluent.MetadataNested<A> withNewMetadata() {
        return new MetadataNestedImpl();
    }

    public ClusterServiceVersionFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
        return new MetadataNestedImpl(item);
    }

    public ClusterServiceVersionFluent.MetadataNested<A> editMetadata() {
        return withNewMetadataLike(getMetadata());
    }

    public ClusterServiceVersionFluent.MetadataNested<A> editOrNewMetadata() {
        return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public ClusterServiceVersionFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
        return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public ClusterServiceVersionSpec getSpec() {
        return this.spec!=null?this.spec.build():null;
    }

    public ClusterServiceVersionSpec buildSpec() {
        return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(ClusterServiceVersionSpec spec) {
        _visitables.get("spec").remove(this.spec);
        if (spec!=null){ this.spec= new ClusterServiceVersionSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
    }

    public Boolean hasSpec() {
        return this.spec != null;
    }

    public ClusterServiceVersionFluent.SpecNested<A> withNewSpec() {
        return new SpecNestedImpl();
    }

    public ClusterServiceVersionFluent.SpecNested<A> withNewSpecLike(ClusterServiceVersionSpec item) {
        return new SpecNestedImpl(item);
    }

    public ClusterServiceVersionFluent.SpecNested<A> editSpec() {
        return withNewSpecLike(getSpec());
    }

    public ClusterServiceVersionFluent.SpecNested<A> editOrNewSpec() {
        return withNewSpecLike(getSpec() != null ? getSpec(): new ClusterServiceVersionSpecBuilder().build());
    }

    public ClusterServiceVersionFluent.SpecNested<A> editOrNewSpecLike(ClusterServiceVersionSpec item) {
        return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public ClusterServiceVersionStatus getStatus() {
        return this.status!=null?this.status.build():null;
    }

    public ClusterServiceVersionStatus buildStatus() {
        return this.status!=null?this.status.build():null;
    }

    public A withStatus(ClusterServiceVersionStatus status) {
        _visitables.get("status").remove(this.status);
        if (status!=null){ this.status= new ClusterServiceVersionStatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
    }

    public Boolean hasStatus() {
        return this.status != null;
    }

    public ClusterServiceVersionFluent.StatusNested<A> withNewStatus() {
        return new StatusNestedImpl();
    }

    public ClusterServiceVersionFluent.StatusNested<A> withNewStatusLike(ClusterServiceVersionStatus item) {
        return new StatusNestedImpl(item);
    }

    public ClusterServiceVersionFluent.StatusNested<A> editStatus() {
        return withNewStatusLike(getStatus());
    }

    public ClusterServiceVersionFluent.StatusNested<A> editOrNewStatus() {
        return withNewStatusLike(getStatus() != null ? getStatus(): new ClusterServiceVersionStatusBuilder().build());
    }

    public ClusterServiceVersionFluent.StatusNested<A> editOrNewStatusLike(ClusterServiceVersionStatus item) {
        return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ClusterServiceVersionFluentImpl that = (ClusterServiceVersionFluentImpl) o;
        if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
        if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
        if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
        if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
        if (status != null ? !status.equals(that.status) :that.status != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
    }

    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ClusterServiceVersionFluent.MetadataNested<N>> implements ClusterServiceVersionFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final ObjectMetaBuilder builder;

            MetadataNestedImpl(ObjectMeta item) {
                this.builder = new ObjectMetaBuilder(this, item);
                        
            }

            MetadataNestedImpl() {
                this.builder = new ObjectMetaBuilder(this);
                        
            }

            public N and() {
                return (N) ClusterServiceVersionFluentImpl.this.withMetadata(builder.build());
            }

            public N endMetadata() {
                return and();
            }
    }


    public class SpecNestedImpl<N> extends ClusterServiceVersionSpecFluentImpl<ClusterServiceVersionFluent.SpecNested<N>> implements ClusterServiceVersionFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final ClusterServiceVersionSpecBuilder builder;

            SpecNestedImpl(ClusterServiceVersionSpec item) {
                this.builder = new ClusterServiceVersionSpecBuilder(this, item);
                        
            }

            SpecNestedImpl() {
                this.builder = new ClusterServiceVersionSpecBuilder(this);
                        
            }

            public N and() {
                return (N) ClusterServiceVersionFluentImpl.this.withSpec(builder.build());
            }

            public N endSpec() {
                return and();
            }
    }


    public class StatusNestedImpl<N> extends ClusterServiceVersionStatusFluentImpl<ClusterServiceVersionFluent.StatusNested<N>> implements ClusterServiceVersionFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final ClusterServiceVersionStatusBuilder builder;

            StatusNestedImpl(ClusterServiceVersionStatus item) {
                this.builder = new ClusterServiceVersionStatusBuilder(this, item);
                        
            }

            StatusNestedImpl() {
                this.builder = new ClusterServiceVersionStatusBuilder(this);
                        
            }

            public N and() {
                return (N) ClusterServiceVersionFluentImpl.this.withStatus(builder.build());
            }

            public N endStatus() {
                return and();
            }
    }


}

==> openshift-model-operatorhub-5.3.1-sources.jar: annotations/io/fabric8/openshift/api/model/operatorhub/v1alpha1/ClusterServiceVersionFluentImpl.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import java.lang.Object;

public class ClusterServiceVersionFluentImpl<A extends ClusterServiceVersionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ClusterServiceVersionFluent<A> {

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private ClusterServiceVersionSpecBuilder spec;
    private ClusterServiceVersionStatusBuilder status;

    public ClusterServiceVersionFluentImpl() {
    }

    public ClusterServiceVersionFluentImpl(ClusterServiceVersion instance) {
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion() {
        return this.apiVersion;
    }

    public A withApiVersion(String apiVersion) {
        this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion() {
        return this.apiVersion != null;
    }

    public A withNewApiVersion(StringBuilder arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(int[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(char[] arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(byte[] arg1,int arg2) {
        return (A)withApiVersion(new String(arg1, arg2));
    }

    public A withNewApiVersion(byte[] arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(char[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(byte[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withApiVersion(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewApiVersion(String arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public String getKind() {
        return this.kind;
    }

    public A withKind(String kind) {
        this.kind=kind; return (A) this;
    }

    public Boolean hasKind() {
        return this.kind != null;
    }

    public A withNewKind(StringBuilder arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(int[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(char[] arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(byte[] arg1,int arg2) {
        return (A)withKind(new String(arg1, arg2));
    }

    public A withNewKind(byte[] arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(char[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(byte[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withKind(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewKind(String arg1) {
        return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata() {
        return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata() {
        return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata) {
        _visitables.get("metadata").remove(this.metadata);
        if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata() {
        return this.metadata != null;
    }

    public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ClusterServiceVersionFluent.MetadataNested<A> withNewMetadata() {
        return new MetadataNestedImpl();
    }

    public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ClusterServiceVersionFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
        return new MetadataNestedImpl(item);
    }

    public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ClusterServiceVersionFluent.MetadataNested<A> editMetadata() {
        return withNewMetadataLike(getMetadata());
    }

    public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ClusterServiceVersionFluent.MetadataNested<A> editOrNewMetadata() {
        return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ClusterServiceVersionFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
        return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public ClusterServiceVersionSpec getSpec() {
        return this.spec!=null?this.spec.build():null;
    }

    public ClusterServiceVersionSpec buildSpec() {
        return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(ClusterServiceVersionSpec spec) {
        _visitables.get("spec").remove(this.spec);
        if (spec!=null){ this.spec= new ClusterServiceVersionSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
    }

    public Boolean hasSpec() {
        return this.spec != null;
    }

    public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ClusterServiceVersionFluent.SpecNested<A> withNewSpec() {
        return new SpecNestedImpl();
    }

    public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ClusterServiceVersionFluent.SpecNested<A> withNewSpecLike(ClusterServiceVersionSpec item) {
        return new SpecNestedImpl(item);
    }

    public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ClusterServiceVersionFluent.SpecNested<A> editSpec() {
        return withNewSpecLike(getSpec());
    }

    public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ClusterServiceVersionFluent.SpecNested<A> editOrNewSpec() {
        return withNewSpecLike(getSpec() != null ? getSpec(): new ClusterServiceVersionSpecBuilder().build());
    }

    public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ClusterServiceVersionFluent.SpecNested<A> editOrNewSpecLike(ClusterServiceVersionSpec item) {
        return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public ClusterServiceVersionStatus getStatus() {
        return this.status!=null?this.status.build():null;
    }

    public ClusterServiceVersionStatus buildStatus() {
        return this.status!=null?this.status.build():null;
    }

    public A withStatus(ClusterServiceVersionStatus status) {
        _visitables.get("status").remove(this.status);
        if (status!=null){ this.status= new ClusterServiceVersionStatusBuilder(status); _visitables.get("status").add(this.status);} return (A) this;
    }

    public Boolean hasStatus() {
        return this.status != null;
    }

    public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ClusterServiceVersionFluent.StatusNested<A> withNewStatus() {
        return new StatusNestedImpl();
    }

    public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ClusterServiceVersionFluent.StatusNested<A> withNewStatusLike(ClusterServiceVersionStatus item) {
        return new StatusNestedImpl(item);
    }

    public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ClusterServiceVersionFluent.StatusNested<A> editStatus() {
        return withNewStatusLike(getStatus());
    }

    public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ClusterServiceVersionFluent.StatusNested<A> editOrNewStatus() {
        return withNewStatusLike(getStatus() != null ? getStatus(): new ClusterServiceVersionStatusBuilder().build());
    }

    public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ClusterServiceVersionFluent.StatusNested<A> editOrNewStatusLike(ClusterServiceVersionStatus item) {
        return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ClusterServiceVersionFluentImpl that = (ClusterServiceVersionFluentImpl) o;
        if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
        if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
        if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
        if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
        if (status != null ? !status.equals(that.status) :that.status != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
    }

    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ClusterServiceVersionFluent.MetadataNested<N>> implements io.fabric8.openshift.api.model.operatorhub.v1alpha1.ClusterServiceVersionFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final ObjectMetaBuilder builder;

            MetadataNestedImpl(ObjectMeta item) {
                this.builder = new ObjectMetaBuilder(this, item);
                        
            }

            MetadataNestedImpl() {
                this.builder = new ObjectMetaBuilder(this);
                        
            }

            public N and() {
                return (N) ClusterServiceVersionFluentImpl.this.withMetadata(builder.build());
            }

            public N endMetadata() {
                return and();
            }
    }


    public class SpecNestedImpl<N> extends ClusterServiceVersionSpecFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ClusterServiceVersionFluent.SpecNested<N>> implements io.fabric8.openshift.api.model.operatorhub.v1alpha1.ClusterServiceVersionFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final ClusterServiceVersionSpecBuilder builder;

            SpecNestedImpl(ClusterServiceVersionSpec item) {
                this.builder = new ClusterServiceVersionSpecBuilder(this, item);
                        
            }

            SpecNestedImpl() {
                this.builder = new ClusterServiceVersionSpecBuilder(this);
                        
            }

            public N and() {
                return (N) ClusterServiceVersionFluentImpl.this.withSpec(builder.build());
            }

            public N endSpec() {
                return and();
            }
    }


    public class StatusNestedImpl<N> extends ClusterServiceVersionStatusFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ClusterServiceVersionFluent.StatusNested<N>> implements io.fabric8.openshift.api.model.operatorhub.v1alpha1.ClusterServiceVersionFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final ClusterServiceVersionStatusBuilder builder;

            StatusNestedImpl(ClusterServiceVersionStatus item) {
                this.builder = new ClusterServiceVersionStatusBuilder(this, item);
                        
            }

            StatusNestedImpl() {
                this.builder = new ClusterServiceVersionStatusBuilder(this);
                        
            }

            public N and() {
                return (N) ClusterServiceVersionFluentImpl.this.withStatus(builder.build());
            }

            public N endStatus() {
                return and();
            }
    }


}
